==> rutorrent-5.2.9.tar.gz: ruTorrent-5.2.9/plugins/geoip/lang/pt-br.js <==
﻿/*
 * PLUGIN GEOIP
 *
 * Portuguese (Brazil) language file.
 *
 * Initial Author: art.spb, December 2009.
 *
 * Author: 
 */

 theUILang.peerComment		= "Adicionar comentário";
 theUILang.peerCommentLabel	= "Digite um novo comentário para o par";
 theUILang.commentName		= "Comentário";
 theUILang.countryName		= "País";

 theUILang.country = new Array();
 theUILang.country[ "ad" ] = "Andorra";
 theUILang.country[ "ae" ] = "Emirados Árabes Unidos";
 theUILang.country[ "af" ] = "Afeganistão";
 theUILang.country[ "ag" ] = "Antígua e Barbuda";
 theUILang.country[ "ai" ] = "Anguilla";
 theUILang.country[ "al" ] = "Albânia";
 theUILang.country[ "am" ] = "Armenia";
 theUILang.country[ "ao" ] = "Angola";
 theUILang.country[ "aq" ] = "Antártida";
 theUILang.country[ "ar" ] = "Argentina";
 theUILang.country[ "as" ] = "Samoa Americana";
 theUILang.country[ "at" ] = "Áustria";
 theUILang.country[ "au" ] = "Austrália";
 theUILang.country[ "aw" ] = "Aruba";
 theUILang.country[ "ax" ] = "Ilhas Åland";
 theUILang.country[ "az" ] = "Azerbaijão";
 theUILang.country[ "ba" ] = "Bósnia e Herzegovina";
 theUILang.country[ "bb" ] = "Barbados";
 theUILang.country[ "bd" ] = "Bangladesh";
 theUILang.country[ "be" ] = "Bélgica";
 theUILang.country[ "bf" ] = "Burkina Faso";
 theUILang.country[ "bg" ] = "Bulgária";
 theUILang.country[ "bh" ] = "Bahrain";
 theUILang.country[ "bi" ] = "Burundi";
 theUILang.country[ "bj" ] = "Benin";
 theUILang.country[ "bl" ] = "São Bartolomeu";
 theUILang.country[ "bm" ] = "Bermuda";
 theUILang.country[ "bn" ] = "Brunei";
 theUILang.country[ "bo" ] = "Bolívia";
 theUILang.country[ "bq" ] = "Bonaire";
 theUILang.country[ "br" ] = "Brasil";
 theUILang.country[ "bs" ] = "Bahamas";
 theUILang.country[ "bt" ] = "Butão";
 theUILang.country[ "bv" ] = "Ilha Bouvet";
 theUILang.country[ "bw" ] = "Botswana";
 theUILang.country[ "by" ] = "Bielorrússia";
 theUILang.country[ "bz" ] = "Belize";
 theUILang.country[ "ca" ] = "Canadá";
 theUILang.country[ "cc" ] = "Ilhas Cocos";
 theUILang.country[ "cd" ] = "Congo (Kinshasa)";
 theUILang.country[ "cf" ] = "República Centro-Africana";
 theUILang.country[ "cg" ] = "Congo (Brazzaville)";
 theUILang.country[ "ch" ] = "Suíça";
 theUILang.country[ "ci" ] = "Costa do Marfim";
 theUILang.country[ "ck" ] = "Ilhas Cook";
 theUILang.country[ "cl" ] = "Chile";
 theUILang.country[ "cm" ] = "Camarões";
 theUILang.country[ "cn" ] = "China";
 theUILang.country[ "co" ] = "Colômbia";
 theUILang.country[ "cr" ] = "Costa Rica";
 theUILang.country[ "cu" ] = "Cuba";
 theUILang.country[ "cv" ] = "Cabo Verde";
 theUILang.country[ "cw" ] = "Curaçao";
 theUILang.country[ "cx" ] = "Ilha do Natal";
 theUILang.country[ "cy" ] = "Chipre";
 theUILang.country[ "cz" ] = "República Tcheca";
 theUILang.country[ "de" ] = "Alemanha";
 theUILang.country[ "dj" ] = "Djibouti";
 theUILang.country[ "dk" ] = "Dinamarca";
 theUILang.country[ "dm" ] = "Dominica";
 theUILang.country[ "do" ] = "República Dominicana";
 theUILang.country[ "dz" ] = "Argélia";
 theUILang.country[ "ec" ] = "Equador";
 theUILang.country[ "ee" ] = "Estônia";
 theUILang.country[ "eg" ] = "Egito";
 theUILang.country[ "eh" ] = "Saara Ocidental";
 theUILang.country[ "er" ] = "Eritreia";
 theUILang.country[ "es" ] = "Espanha";
 theUILang.country[ "et" ] = "Etiópia";
 theUILang.country[ "eu" ] = "União Europeia";
 theUILang.country[ "fi" ] = "Finlândia";
 theUILang.country[ "fj" ] = "Fiji";
 theUILang.country[ "fk" ] = "Ilhas Malvinas";
 theUILang.country[ "fm" ] = "Micronésia";
 theUILang.country[ "fo" ] = "Ilhas Faroé";
 theUILang.country[ "fr" ] = "França";
 theUILang.country[ "ga" ] = "Gabão";
 theUILang.country[ "gb" ] = "Reino Unido";
 theUILang.country[ "gd" ] = "Granada";
 theUILang.country[ "ge" ] = "Geórgia";
 theUILang.country[ "gf" ] = "Guiana Francesa";
 theUILang.country[ "gg" ] = "Guernsey";
 theUILang.country[ "gh" ] = "Gana";
 theUILang.country[ "gi" ] = "Gibraltar";
 theUILang.country[ "gl" ] = "Groenlândia";
 theUILang.country[ "gm" ] = "Gâmbia";
 theUILang.country[ "gn" ] = "Guiné";
 theUILang.country[ "gp" ] = "Guadalupe";
 theUILang.country[ "gq" ] = "Guiné Equatorial";
 theUILang.country[ "gr" ] = "Grécia";
 theUILang.country[ "gs" ] = "Ilhas Geórgia do Sul e Sandwich do Sul";
 theUILang.country[ "gt" ] = "Guatemala";
 theUILang.country[ "gu" ] = "Guam";
 theUILang.country[ "gw" ] = "Guiné-Bissau";
 theUILang.country[ "gy" ] = "Guiana";
 theUILang.country[ "hk" ] = "Hong Kong";
 theUILang.country[ "hm" ] = "Ilha Heard e McDonald Ilhas";
 theUILang.country[ "hn" ] = "Honduras";
 theUILang.country[ "hr" ] = "Croácia";
 theUILang.country[ "ht" ] = "Haiti";
 theUILang.country[ "hu" ] = "Hungria";
 theUILang.country[ "id" ] = "Indonésia";
 theUILang.country[ "ie" ] = "Irlanda";
 theUILang.country[ "il" ] = "Israel";
 theUILang.country[ "im" ] = "Ilha de Man";
 theUILang.country[ "in" ] = "Índia";
 theUILang.country[ "io" ] = "Território Britânico do Oceano Índico";
 theUILang.country[ "iq" ] = "Iraque";
 theUILang.country[ "ir" ] = "Irã";
 theUILang.country[ "is" ] = "Islândia";
 theUILang.country[ "it" ] = "Itália";
 theUILang.country[ "je" ] = "Jersey";
 theUILang.country[ "jm" ] = "Jamaica";
 theUILang.country[ "jo" ] = "Jordânia";
 theUILang.country[ "jp" ] = "Japão";
 theUILang.country[ "ke" ] = "Quênia";
 theUILang.country[ "kg" ] = "Quirguistão";
 theUILang.country[ "kh" ] = "Cambodia";
 theUILang.country[ "ki" ] = "Quiribati";
 theUILang.country[ "km" ] = "Comores";
 theUILang.country[ "kn" ] = "São Cristóvão e Nevis";
 theUILang.country[ "kp" ] = "Coreia do Norte";
 theUILang.country[ "kr" ] = "Coreia do Sul";
 theUILang.country[ "kw" ] = "Kuwait";
 theUILang.country[ "ky" ] = "Ilhas Cayman";
 theUILang.country[ "kz" ] = "Cazaquistão";
 theUILang.country[ "la" ] = "Laos";
 theUILang.country[ "lb" ] = "Líbano";
 theUILang.country[ "lc" ] = "Santa Lúcia";
 theUILang.country[ "li" ] = "Liechtenstein";
 theUILang.country[ "lk" ] = "Sri Lanka";
 theUILang.country[ "lr" ] = "Libéria";
 theUILang.country[ "ls" ] = "Lesoto";
 theUILang.country[ "lt" ] = "Lituânia";
 theUILang.country[ "lu" ] = "Luxemburgo";
 theUILang.country[ "lv" ] = "Letónia";
 theUILang.country[ "ly" ] = "Líbia";
 theUILang.country[ "ma" ] = "Marrocos";
 theUILang.country[ "mc" ] = "Monaco";
 theUILang.country[ "md" ] = "Moldávia";
 theUILang.country[ "me" ] = "Montenegro";
 theUILang.country[ "mf" ] = "São Martinho";
 theUILang.country[ "mg" ] = "Madagáscar";
 theUILang.country[ "mh" ] = "Ilhas Marshall";
 theUILang.country[ "mk" ] = "Macedônia do Norte";
 theUILang.country[ "ml" ] = "Mali";
 theUILang.country[ "mm" ] = "Mianmar";
 theUILang.country[ "mn" ] = "Mongólia";
 theUILang.country[ "mo" ] = "Macau";
 theUILang.country[ "mp" ] = "Ilhas Marianas do Norte";
 theUILang.country[ "mq" ] = "Martinica";
 theUILang.country[ "mr" ] = "Mauritânia";
 theUILang.country[ "ms" ] = "Montserrat";
 theUILang.country[ "mt" ] = "Malta";
 theUILang.country[ "mu" ] = "Maurício";
 theUILang.country[ "mv" ] = "Maldivas";
 theUILang.country[ "mw" ] = "Malawi";
 theUILang.country[ "mx" ] = "México";
 theUILang.country[ "my" ] = "Malásia";
 theUILang.country[ "mz" ] = "Moçambique";
 theUILang.country[ "na" ] = "Namibia";
 theUILang.country[ "nc" ] = "Nova Caledónia";
 theUILang.country[ "ne" ] = "Niger";
 theUILang.country[ "nf" ] = "Ilha Norfolk";
 theUILang.country[ "ng" ] = "Nigéria";
 theUILang.country[ "ni" ] = "Nicarágua";
 theUILang.country[ "nl" ] = "Países Baixos";
 theUILang.country[ "no" ] = "Noruega";
 theUILang.country[ "np" ] = "Nepal";
 theUILang.country[ "nr" ] = "Nauru";
 theUILang.country[ "nu" ] = "Niue";
 theUILang.country[ "nz" ] = "Nova Zelândia";
 theUILang.country[ "om" ] = "Omã";
 theUILang.country[ "pa" ] = "Panamá";
 theUILang.country[ "pe" ] = "Peru";
 theUILang.country[ "pf" ] = "Polinésia Francesa";
 theUILang.country[ "pg" ] = "Papua Nova Guiné";
 theUILang.country[ "ph" ] = "Filipinas";
 theUILang.country[ "pk" ] = "Paquistão";
 theUILang.country[ "pl" ] = "Polônia";
 theUILang.country[ "pm" ] = "Saint-Pierre e Miquelon";
 theUILang.country[ "pn" ] = "Ilhas Pitcairn";
 theUILang.country[ "pr" ] = "Porto Rico";
 theUILang.country[ "ps" ] = "Palestina";
 theUILang.country[ "pt" ] = "Portugal";
 theUILang.country[ "pw" ] = "Palau";
 theUILang.country[ "py" ] = "Paraguai";
 theUILang.country[ "qa" ] = "Qatar";
 theUILang.country[ "re" ] = "Reunião";
 theUILang.country[ "ro" ] = "Romênia";
 theUILang.country[ "rs" ] = "Sérvia";
 theUILang.country[ "ru" ] = "Rússia";
 theUILang.country[ "rw" ] = "Ruanda";
 theUILang.country[ "sa" ] = "Arábia Saudita";
 theUILang.country[ "sb" ] = "Ilhas Salomão";
 theUILang.country[ "sc" ] = "Seychelles";
 theUILang.country[ "sd" ] = "Sudão";
 theUILang.country[ "se" ] = "Suécia";
 theUILang.country[ "sg" ] = "Singapura";
 theUILang.country[ "sh" ] = "Santa Helena";
 theUILang.country[ "si" ] = "Eslovênia";
 theUILang.country[ "sj" ] = "Svalbard e Jan Mayen";
 theUILang.country[ "sk" ] = "Eslováquia";
 theUILang.country[ "sl" ] = "Serra Leoa";
 theUILang.country[ "sm" ] = "San Marino";
 theUILang.country[ "sn" ] = "Senegal";
 theUILang.country[ "so" ] = "Somália";
 theUILang.country[ "sr" ] = "Suriname";
 theUILang.country[ "ss" ] = "Sudão do Sul";
 theUILang.country[ "st" ] = "São Tomé e Príncipe";
 theUILang.country[ "sv" ] = "El Salvador";
 theUILang.country[ "sx" ] = "São Martinho (Sint Maarten)";
 theUILang.country[ "sy" ] = "Síria";
 theUILang.country[ "sz" ] = "Essuatíni";
 theUILang.country[ "tc" ] = "Ilhas Turcas e Caicos";
 theUILang.country[ "td" ] = "Chade";
 theUILang.country[ "tf" ] = "Territórios Franceses do Sul";
 theUILang.country[ "tg" ] = "Togo";
 theUILang.country[ "th" ] = "Tailândia";
 theUILang.country[ "tj" ] = "Tajiquistão";
 theUILang.country[ "tk" ] = "Tokelau";
 theUILang.country[ "tl" ] = "Timor-Leste";
 theUILang.country[ "tm" ] = "Turcomenistão";
 theUILang.country[ "tn" ] = "Tunísia";
 theUILang.country[ "to" ] = "Tonga";
 theUILang.country[ "tr" ] = "Turquia";
 theUILang.country[ "tt" ] = "Trinidad e Tobago";
 theUILang.country[ "tv" ] = "Tuvalu";
 theUILang.country[ "tw" ] = "Taiwan";
 theUILang.country[ "tz" ] = "Tanzânia";
 theUILang.country[ "ua" ] = "Ucrânia";
 theUILang.country[ "ug" ] = "Uganda";
 theUILang.country[ "um" ] = "Ilhas Menores Distantes dos EUA";
 theUILang.country[ "un" ] = "Desconhecido";
 theUILang.country[ "us" ] = "Estados Unidos";
 theUILang.country[ "uy" ] = "Uruguai";
 theUILang.country[ "uz" ] = "Uzbequistão";
 theUILang.country[ "va" ] = "Vaticano";
 theUILang.country[ "vc" ] = "São Vicente e Granadinas";
 theUILang.country[ "ve" ] = "Venezuela";
 theUILang.country[ "vg" ] = "Ilhas Virgens Britânicas";
 theUILang.country[ "vi" ] = "Ilhas Virgens Americanas";
 theUILang.country[ "vn" ] = "Vietnã";
 theUILang.country[ "vu" ] = "Vanuatu";
 theUILang.country[ "wf" ] = "Wallis e Futuna";
 theUILang.country[ "ws" ] = "Samoa";
 theUILang.country[ "ye" ] = "Iêmen";
 theUILang.country[ "yt" ] = "Mayotte";
 theUILang.country[ "za" ] = "África do Sul";
 theUILang.country[ "zm" ] = "Zâmbia";
 theUILang.country[ "zw" ] = "Zimbabwe";

thePlugins.get("geoip").langLoaded();

==> rutorrent-5.2.10.tar.gz: ruTorrent-5.2.10/plugins/geoip/lang/pt-br.js <==
/*
 * PLUGIN GEOIP
 *
 * Portuguese (Brazil) language file.
 *
 * Initial Author: art.spb, December 2009.
 *
 * Author: 
 */

 theUILang.peerComment		= "Adicionar comentário";
 theUILang.peerCommentLabel	= "Digite um novo comentário para o par";
 theUILang.commentName		= "Comentário";
 theUILang.countryName		= "País";

 theUILang.country = new Array();
 theUILang.country[ "ad" ] = "Andorra";
 theUILang.country[ "ae" ] = "Emirados Árabes Unidos";
 theUILang.country[ "af" ] = "Afeganistão";
 theUILang.country[ "ag" ] = "Antígua e Barbuda";
 theUILang.country[ "ai" ] = "Anguilla";
 theUILang.country[ "al" ] = "Albânia";
 theUILang.country[ "am" ] = "Armênia";
 theUILang.country[ "ao" ] = "Angola";
 theUILang.country[ "aq" ] = "Antártida";
 theUILang.country[ "ar" ] = "Argentina";
 theUILang.country[ "as" ] = "Samoa Americana";
 theUILang.country[ "at" ] = "Áustria";
 theUILang.country[ "au" ] = "Austrália";
 theUILang.country[ "aw" ] = "Aruba";
 theUILang.country[ "ax" ] = "Ilhas Åland";
 theUILang.country[ "az" ] = "Azerbaijão";
 theUILang.country[ "ba" ] = "Bósnia e Herzegovina";
 theUILang.country[ "bb" ] = "Barbados";
 theUILang.country[ "bd" ] = "Bangladesh";
 theUILang.country[ "be" ] = "Bélgica";
 theUILang.country[ "bf" ] = "Burkina Faso";
 theUILang.country[ "bg" ] = "Bulgária";
 theUILang.country[ "bh" ] = "Bahrein";
 theUILang.country[ "bi" ] = "Burundi";
 theUILang.country[ "bj" ] = "Benim";
 theUILang.country[ "bl" ] = "São Bartolomeu";
 theUILang.country[ "bm" ] = "Bermuda";
 theUILang.country[ "bn" ] = "Brunei";
 theUILang.country[ "bo" ] = "Bolívia";
 theUILang.country[ "bq" ] = "Países Baixos Caribenhos";
 theUILang.country[ "br" ] = "Brasil";
 theUILang.country[ "bs" ] = "Bahamas";
 theUILang.country[ "bt" ] = "Butão";
 theUILang.country[ "bv" ] = "Ilha Bouvet";
 theUILang.country[ "bw" ] = "Botswana";
 theUILang.country[ "by" ] = "Bielorrússia";
 theUILang.country[ "bz" ] = "Belize";
 theUILang.country[ "ca" ] = "Canadá";
 theUILang.country[ "cc" ] = "Ilhas Cocos (Keeling)";
 theUILang.country[ "cd" ] = "Congo (Kinshasa)";
 theUILang.country[ "cf" ] = "República Centro-Africana";
 theUILang.country[ "cg" ] = "Congo (Brazzaville)";
 theUILang.country[ "ch" ] = "Suíça";
 theUILang.country[ "ci" ] = "Costa do Marfim";
 theUILang.country[ "ck" ] = "Ilhas Cook";
 theUILang.country[ "cl" ] = "Chile";
 theUILang.country[ "cm" ] = "Camarões";
 theUILang.country[ "cn" ] = "China";
 theUILang.country[ "co" ] = "Colômbia";
 theUILang.country[ "cr" ] = "Costa Rica";
 theUILang.country[ "cu" ] = "Cuba";
 theUILang.country[ "cv" ] = "Cabo Verde";
 theUILang.country[ "cw" ] = "Curaçao";
 theUILang.country[ "cx" ] = "Ilha do Natal";
 theUILang.country[ "cy" ] = "Chipre";
 theUILang.country[ "cz" ] = "República Tcheca";
 theUILang.country[ "de" ] = "Alemanha";
 theUILang.country[ "dj" ] = "Djibuti";
 theUILang.country[ "dk" ] = "Dinamarca";
 theUILang.country[ "dm" ] = "Dominica";
 theUILang.country[ "do" ] = "República Dominicana";
 theUILang.country[ "dz" ] = "Argélia";
 theUILang.country[ "ec" ] = "Equador";
 theUILang.country[ "ee" ] = "Estônia";
 theUILang.country[ "eg" ] = "Egito";
 theUILang.country[ "eh" ] = "Saara Ocidental";
 theUILang.country[ "er" ] = "Eritreia";
 theUILang.country[ "es" ] = "Espanha";
 theUILang.country[ "et" ] = "Etiópia";
 theUILang.country[ "eu" ] = "União Europeia";
 theUILang.country[ "fi" ] = "Finlândia";
 theUILang.country[ "fj" ] = "Fiji";
 theUILang.country[ "fk" ] = "Ilhas Malvinas";
 theUILang.country[ "fm" ] = "Estados Federados da Micronésia";
 theUILang.country[ "fo" ] = "Ilhas Faroé";
 theUILang.country[ "fr" ] = "França";
 theUILang.country[ "ga" ] = "Gabão";
 theUILang.country[ "gb" ] = "Reino Unido";
 theUILang.country[ "gd" ] = "Granada";
 theUILang.country[ "ge" ] = "Geórgia";
 theUILang.country[ "gf" ] = "Guiana Francesa";
 theUILang.country[ "gg" ] = "Guernsey";
 theUILang.country[ "gh" ] = "Gana";
 theUILang.country[ "gi" ] = "Gibraltar";
 theUILang.country[ "gl" ] = "Gronelândia";
 theUILang.country[ "gm" ] = "Gâmbia";
 theUILang.country[ "gn" ] = "Guiné";
 theUILang.country[ "gp" ] = "Guadalupe";
 theUILang.country[ "gq" ] = "Guiné Equatorial";
 theUILang.country[ "gr" ] = "Grécia";
 theUILang.country[ "gs" ] = "Ilhas Geórgia do Sul e Sanduíche do Sul";
 theUILang.country[ "gt" ] = "Guatemala";
 theUILang.country[ "gu" ] = "Guam";
 theUILang.country[ "gw" ] = "Guiné-Bissau";
 theUILang.country[ "gy" ] = "Guiana";
 theUILang.country[ "hk" ] = "Hong Kong";
 theUILang.country[ "hm" ] = "Ilha Heard e Ilhas McDonald";
 theUILang.country[ "hn" ] = "Honduras";
 theUILang.country[ "hr" ] = "Croácia";
 theUILang.country[ "ht" ] = "Haiti";
 theUILang.country[ "hu" ] = "Hungria";
 theUILang.country[ "id" ] = "Indonésia";
 theUILang.country[ "ie" ] = "Irlanda";
 theUILang.country[ "il" ] = "Israel";
 theUILang.country[ "im" ] = "Ilha de Man";
 theUILang.country[ "in" ] = "Índia";
 theUILang.country[ "io" ] = "Território Britânico do Oceano Índico";
 theUILang.country[ "iq" ] = "Iraque";
 theUILang.country[ "ir" ] = "Irã";
 theUILang.country[ "is" ] = "Islândia";
 theUILang.country[ "it" ] = "Itália";
 theUILang.country[ "je" ] = "Jersey";
 theUILang.country[ "jm" ] = "Jamaica";
 theUILang.country[ "jo" ] = "Jordânia";
 theUILang.country[ "jp" ] = "Japão";
 theUILang.country[ "ke" ] = "Quênia";
 theUILang.country[ "kg" ] = "Quirguistão";
 theUILang.country[ "kh" ] = "Camboja";
 theUILang.country[ "ki" ] = "Kiribati";
 theUILang.country[ "km" ] = "Comores";
 theUILang.country[ "kn" ] = "São Cristóvão e Nevis";
 theUILang.country[ "kp" ] = "Coreia do Norte";
 theUILang.country[ "kr" ] = "Coreia do Sul";
 theUILang.country[ "kw" ] = "Kuwait";
 theUILang.country[ "ky" ] = "Ilhas Cayman";
 theUILang.country[ "kz" ] = "Cazaquistão";
 theUILang.country[ "la" ] = "Laos";
 theUILang.country[ "lb" ] = "Líbano";
 theUILang.country[ "lc" ] = "Santa Lúcia";
 theUILang.country[ "li" ] = "Liechtenstein";
 theUILang.country[ "lk" ] = "Sri Lanka";
 theUILang.country[ "lr" ] = "Libéria";
 theUILang.country[ "ls" ] = "Lesoto";
 theUILang.country[ "lt" ] = "Lituânia";
 theUILang.country[ "lu" ] = "Luxemburgo";
 theUILang.country[ "lv" ] = "Letônia";
 theUILang.country[ "ly" ] = "Líbia";
 theUILang.country[ "ma" ] = "Marrocos";
 theUILang.country[ "mc" ] = "Mônaco";
 theUILang.country[ "md" ] = "Moldávia";
 theUILang.country[ "me" ] = "Montenegro";
 theUILang.country[ "mf" ] = "São Martinho (França)";
 theUILang.country[ "mg" ] = "Madagáscar";
 theUILang.country[ "mh" ] = "Ilhas Marshall";
 theUILang.country[ "mk" ] = "Macedônia do Norte";
 theUILang.country[ "ml" ] = "Mali";
 theUILang.country[ "mm" ] = "Mianmar";
 theUILang.country[ "mn" ] = "Mongólia";
 theUILang.country[ "mo" ] = "Macau";
 theUILang.country[ "mp" ] = "Ilhas Marianas do Norte";
 theUILang.country[ "mq" ] = "Martinica";
 theUILang.country[ "mr" ] = "Mauritânia";
 theUILang.country[ "ms" ] = "Montserrat";
 theUILang.country[ "mt" ] = "Malta";
 theUILang.country[ "mu" ] = "Maurício";
 theUILang.country[ "mv" ] = "Maldivas";
 theUILang.country[ "mw" ] = "Malawi";
 theUILang.country[ "mx" ] = "México";
 theUILang.country[ "my" ] = "Malásia";
 theUILang.country[ "mz" ] = "Moçambique";
 theUILang.country[ "na" ] = "Namíbia";
 theUILang.country[ "nc" ] = "Nova Caledônia";
 theUILang.country[ "ne" ] = "Níger";
 theUILang.country[ "nf" ] = "Ilha Norfolk";
 theUILang.country[ "ng" ] = "Nigéria";
 theUILang.country[ "ni" ] = "Nicarágua";
 theUILang.country[ "nl" ] = "Países Baixos";
 theUILang.country[ "no" ] = "Noruega";
 theUILang.country[ "np" ] = "Nepal";
 theUILang.country[ "nr" ] = "Nauru";
 theUILang.country[ "nu" ] = "Niue";
 theUILang.country[ "nz" ] = "Nova Zelândia";
 theUILang.country[ "om" ] = "Omã";
 theUILang.country[ "pa" ] = "Panamá";
 theUILang.country[ "pe" ] = "Peru";
 theUILang.country[ "pf" ] = "Polinésia Francesa";
 theUILang.country[ "pg" ] = "Papua Nova Guiné";
 theUILang.country[ "ph" ] = "Filipinas";
 theUILang.country[ "pk" ] = "Paquistão";
 theUILang.country[ "pl" ] = "Polônia";
 theUILang.country[ "pm" ] = "São Pedro e Miquelão";
 theUILang.country[ "pn" ] = "Ilhas Pitcairn";
 theUILang.country[ "pr" ] = "Porto Rico";
 theUILang.country[ "ps" ] = "Palestina";
 theUILang.country[ "pt" ] = "Portugal";
 theUILang.country[ "pw" ] = "Palau";
 theUILang.country[ "py" ] = "Paraguai";
 theUILang.country[ "qa" ] = "Catar";
 theUILang.country[ "re" ] = "Reunião";
 theUILang.country[ "ro" ] = "Romênia";
 theUILang.country[ "rs" ] = "Sérvia";
 theUILang.country[ "ru" ] = "Rússia";
 theUILang.country[ "rw" ] = "Ruanda";
 theUILang.country[ "sa" ] = "Arábia Saudita";
 theUILang.country[ "sb" ] = "Ilhas Salomão";
 theUILang.country[ "sc" ] = "Seicheles";
 theUILang.country[ "sd" ] = "Sudão";
 theUILang.country[ "se" ] = "Suécia";
 theUILang.country[ "sg" ] = "Singapura";
 theUILang.country[ "sh" ] = "Santa Helena";
 theUILang.country[ "si" ] = "Eslovênia";
 theUILang.country[ "sj" ] = "Svalbard e Jan Mayen";
 theUILang.country[ "sk" ] = "Eslováquia";
 theUILang.country[ "sl" ] = "Serra Leoa";
 theUILang.country[ "sm" ] = "San Marino";
 theUILang.country[ "sn" ] = "Senegal";
 theUILang.country[ "so" ] = "Somália";
 theUILang.country[ "sr" ] = "Suriname";
 theUILang.country[ "ss" ] = "Sudão do Sul";
 theUILang.country[ "st" ] = "São Tomé e Príncipe";
 theUILang.country[ "sv" ] = "El Salvador";
 theUILang.country[ "sx" ] = "São Martinho (Holanda)";
 theUILang.country[ "sy" ] = "Síria";
 theUILang.country[ "sz" ] = "Essuatíni";
 theUILang.country[ "tc" ] = "Ilhas Turcas e Caicos";
 theUILang.country[ "td" ] = "Chade";
 theUILang.country[ "tf" ] = "Terras Austrais e Antárticas Francesas";
 theUILang.country[ "tg" ] = "Togo";
 theUILang.country[ "th" ] = "Tailândia";
 theUILang.country[ "tj" ] = "Tajiquistão";
 theUILang.country[ "tk" ] = "Tokelau";
 theUILang.country[ "tl" ] = "Timor-Leste";
 theUILang.country[ "tm" ] = "Turquemenistão";
 theUILang.country[ "tn" ] = "Tunísia";
 theUILang.country[ "to" ] = "Tonga";
 theUILang.country[ "tr" ] = "Turquia";
 theUILang.country[ "tt" ] = "Trinidad e Tobago";
 theUILang.country[ "tv" ] = "Tuvalu";
 theUILang.country[ "tw" ] = "Taiwan";
 theUILang.country[ "tz" ] = "Tanzânia";
 theUILang.country[ "ua" ] = "Ucrânia";
 theUILang.country[ "ug" ] = "Uganda";
 theUILang.country[ "um" ] = "Ilhas Menores Distantes dos EUA";
 theUILang.country[ "un" ] = "Desconhecido";
 theUILang.country[ "us" ] = "Estados Unidos";
 theUILang.country[ "uy" ] = "Uruguai";
 theUILang.country[ "uz" ] = "Uzbequistão";
 theUILang.country[ "va" ] = "Cidade do Vaticano";
 theUILang.country[ "vc" ] = "São Vicente e Granadinas";
 theUILang.country[ "ve" ] = "Venezuela";
 theUILang.country[ "vg" ] = "Ilhas Virgens Britânicas";
 theUILang.country[ "vi" ] = "Ilhas Virgens Americanas";
 theUILang.country[ "vn" ] = "Vietnã";
 theUILang.country[ "vu" ] = "Vanuatu";
 theUILang.country[ "wf" ] = "Wallis e Futuna";
 theUILang.country[ "ws" ] = "Samoa";
 theUILang.country[ "ye" ] = "Iêmen";
 theUILang.country[ "yt" ] = "Mayotte";
 theUILang.country[ "za" ] = "África do Sul";
 theUILang.country[ "zm" ] = "Zâmbia";
 theUILang.country[ "zw" ] = "Zimbábue";

thePlugins.get("geoip").langLoaded();
